@@ -140,14 +140,19 @@ class SoundStreamTrainer(nn.Module):
         ema_update_every = 10,
         apply_grad_penalty_every = 4,
         dl_num_workers = 0,
+        accelerator: Accelerator = None,
         accelerate_kwargs: dict = dict(),
         use_lion = False,
         force_clear_prev_results = None  # set to True | False to skip the prompt
     ):
         super().__init__()
 
-        kwargs = DistributedDataParallelKwargs(find_unused_parameters = True)
-        self.accelerator = Accelerator(kwargs_handlers = [kwargs], **accelerate_kwargs)
+        if accelerator:
+            self.accelerator = accelerator
+            assert len(accelerate_kwargs) == 0
+        else:
+            kwargs = DistributedDataParallelKwargs(find_unused_parameters = True)
+            self.accelerator = Accelerator(kwargs_handlers = [kwargs], **accelerate_kwargs)
 
         self.soundstream = soundstream
 
@@ -963,7 +968,7 @@ class CoarseTransformerTrainer(nn.Module):
         # save model every so often
 
         if self.is_main and not (steps % self.save_model_every):
-            model_path = str(self.results_folder / f'fine.transformer.{steps}.pt')
+            model_path = str(self.results_folder / f'coarse.transformer.{steps}.pt')
             self.save(model_path)
 
             self.print(f'{steps}: saving model to {str(self.results_folder)}')
